// java wrapper for vtkAssemblyNode object
//

package vtk;
import vtk.*;

public class vtkAssemblyNode extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetViewProp_2(vtkProp id0);
  public void SetViewProp(vtkProp id0)
    { SetViewProp_2(id0); }

  private native long GetViewProp_3();
  public vtkProp GetViewProp() {
    long temp = GetViewProp_3();

    if (temp == 0) return null;
    return (vtkProp)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetMatrix_4(vtkMatrix4x4 id0);
  public void SetMatrix(vtkMatrix4x4 id0)
    { SetMatrix_4(id0); }

  private native long GetMatrix_5();
  public vtkMatrix4x4 GetMatrix() {
    long temp = GetMatrix_5();

    if (temp == 0) return null;
    return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetMTime_6();
  public int GetMTime()
    { return GetMTime_6(); }

  public vtkAssemblyNode() { super(); }

  public vtkAssemblyNode(long id) { super(id); }
  public native long   VTKInit();

}
